<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Perihal</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Penulis</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lesen</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Pelayan web ringan berasaskan WebKit</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Bahasa</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Bahasa di dalam turutan minat:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Naik A&amp;tas</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Turun Ba&amp;wah</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Keluarkan</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Tambah...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Peraturan</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Tambah Tandabuku</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Taipkan nama tandabuku dan pilih di mana harus disimpan.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tajuk</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Tambah Folder</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Buang</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Buka di Tab Baru</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Folder Baru</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Tandabuku</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Buang</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Tambah Folder</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Sunting Nama</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Sunting Alamat</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Ralat semasa menyimpan tanda buku pada baris %1, lajur %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Bar Alat Tandabuku</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Buka Fail</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>%1 diimport</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Simpan Fail</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Ralat eksport</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>ralat menyimpan tandabuku</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Buang Tandabuku</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Masukkan tandabuku</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Perubahan Nama</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Alamat Berubah</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Bar Tandabuku</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menu Tandabuku</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml *.html)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml *.html)</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Ralat semasa memuatkan tandabuku html: %1
</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">Perubahan Nama</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">Alamat Berubah</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Buka di Tab</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Tajuk</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Tandabuku</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Buka di &amp;Tab Baru</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Buang</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Tambah Tandabuku...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Tambah Folder...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Tandabuku</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Ubah: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Terdapat %1 tetingkap dan %2 tab masih terbuka
Teruskan untuk keluar?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Gagal mengembalikan</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Arora gagal berfungsi semasa cuba mengembalikan sessi yang disimpan. Sessi berkenaan tidak akan dikembalikan.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>Tetin&amp;gkap Baru</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>Buka &amp;Fail...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Buka &amp;Lokasi...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Simpan Sebagai...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Import Tandabuku...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Eksport Tandabuku...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>P&amp;rapapar Pencetak...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Pencetak...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Melungsur secara pri&amp;vasi...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edit</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Batal</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Semula</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>P&amp;otong</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Sa&amp;lin</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Tam&amp;pal</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Cari</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Ca&amp;ri Seterusnya</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>C&amp;ari Sebelumnya</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Opsye&amp;n...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Lihat</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Papar Bar Menu</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Henti</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Muatsemula Laman</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">&amp;Besarkan Text</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">&amp;Normalkan Text</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">&amp;Kecilkan Text</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>S&amp;umber Laman</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>S&amp;krin Penuh</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Sejarah</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Undur</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Maju</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Laman Utama</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Kembalikan Sessi Akhir</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>Tanda&amp;buku</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Urus Tandabuku...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Tambah Tandabuku...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>Tetin&amp;gkap</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Alatan</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Carian Web</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Hapus Data Peribadi</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Benarkan Peny&amp;iasat Web</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Bant&amp;uan</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Tukar bahasa aplikasi</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Perihal &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">Perihal &amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigasi</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Papar Bar Status</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Sembunyi Bar Status</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Papar Bar Alat</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Sembunyi Bar Alat</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Papar Bar Tandabuku</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Sembunyi Bar Tandabuku</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Buka Sumber Web</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Sumber Web (*.html *.htm *.svg *.png *.gif *.svgz);;Semua fail (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Cetak Dokumen</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Anda pasti ingin membuka lungsuran secara privasi?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Apabila lungsuran secara privasi sedang dibuka, Aksi yang melibatkan privasi anda dilumpuhkan:&lt;ul&gt;&lt;li&gt; Laman yang dilawati tidak ditambah ke sejarah.&lt;/li&gt;&lt;li&gt; Senarai muaturun dibersihkan.&lt;/li&gt;&lt;li&gt; Cookies baru tidak disimpan, cookies semasa tidak boleh dicapai.&lt;/li&gt;&lt;li&gt; Ikon laman web dan sessi tidak disimpan.&lt;/li&gt;&lt;li&gt; Carian tidak disimpan di menu popup kotak carian.&lt;/li&gt;&lt;/ul&gt;Selagi tetingkap tidak ditutup, anda masih boleh klik pada butang Undur dan Maju untuk kembalik ke laman yang pernah dibuka.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation type="obsolete">Anda pasti ingin menutup tetingkap ini? Masih ada %1 tab terbuka</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Penyiasat Web</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Penyiasat Web cuma akan berfungsi dengan baik di laman yang dibuka selepas ia dibenarkan berfungsi. 
Anda mahu memuatsemula kesemua laman?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Henti memuat laman semasa</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Muatsemula laman semasa</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Muaturun</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Papar Penyelia Rangkaia&amp;n</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Anda pasti ingin menutup tetingkap ini? Masih ada %1 tab yang terbuka</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Tutup Tetingkap</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom Ke Da&amp;lam</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>Zoom &amp;Normal</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;Keluar</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Zoom &amp;Teks Sahaja</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Papar Kesemua Tandabuku...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Tambah Folder...</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translatorcomment>Perihal Pelayar</translatorcomment>
        <translation>Perihal &amp;%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Apabila lungsuran privasi dipasang, sebahagian tindakan melibatkan privasi akan di lumpuhkan:&lt;ul&gt;&lt;li&gt; Laman web tidak disimpan di dalam sejarah.&lt;/li&gt;&lt;li&gt; Senarai muaturun akan dikeluarkan dari tetingkap Muaturun.&lt;/li&gt;&lt;li&gt; Cookies baru tidak akan disimpan dan cookies semasa tidak dapat digunakan.&lt;/li&gt;&lt;li&gt; Ikon laman web tidak disimpan, sessi tidak disimpan.&lt;/li&gt;&lt;li&gt; Carian tidak ditambah pada menu popup di kekotak carian.&lt;/li&gt;&lt;/ul&gt;Sebelum anda menutup tetingkap, anda masih boleh menggunakan butang Undur dan Maju untuk kembali ke laman web yang pernah di buka.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translatorcomment>Pengurus Muaturun</translatorcomment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Lalai</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Hapus Data Peribadi</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Hapuskan perkara berikut:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Sejarah &amp;Lungsuran</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Sejarah &amp;Muaturun</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Sejarah &amp;Carian</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>Coo&amp;kie</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>C&amp;ache Laman Web</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>&amp;Ikon Laman web</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>&amp;Hapus Data Peribadi</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Batal</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Laman web</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Peraturan</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Benar</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Larang</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Benarkan Untuk Sessi</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Laman web</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Path</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Selamat</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Luput</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Kandungan</translation>
    </message>
    <message>
        <source>true</source>
        <translation>true</translation>
    </message>
    <message>
        <source>false</source>
        <translation>false</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookie</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Buang</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Buang Semu&amp;a Cookie</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Pengecualian Cookie</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Cookie Baru</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domain:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Larang</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Benarkan Untuk Sessi</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Benar</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Pengecualian</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Buang</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Buang Semu&amp;a</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Muaturun</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Bersihkan</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 perkara</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nama fail</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Cuba Semula</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Henti</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Simpan Fail</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Muaturun dibatalkan: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Ralat membuka fail keluaran: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Ralat menyimpan: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Ralat Rangkaian: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">saat</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>lagi %n minit</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>lagi %n saat</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 dari %2 (%3/saat) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 of %2 - Berhenti</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">byte</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">MB</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 dari %2 (%3/saat) - %4</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Muaturun</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Masih ada %1 proses muaturun berjalan
Anda masih ingin keluar?</translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>lagi %n minit</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>lagi %n saat</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Sejarah</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Buang</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Buang Semu&amp;a</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Tunjuk Semua Sejarah</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Hapus Sejarah...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Hapus Sejarah</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Anda mahu hapus sejarah?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Tajuk</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Awal Hari Ini</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n perkara</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>System locale (%1) %2</source>
        <translation type="obsolete">Sistem Lokal (%1) %2</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Pilih bahasa</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Anda boleh menggunakan bahasa selain dari&lt;br&gt;tetapan sistem operasi.&lt;/p&gt;&lt;p&gt;Sila pilih bahasa yang harus digunakan&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Lalai</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Fail terjemahan tidak dipasang.</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Masukkan nama pengguna dan katalaluan untuk &quot;%1&quot; di %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Berhubung dengan proxy &quot;%1&quot; menggunakan:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">Ralat SSL:

%1

%2

Anda mahu abaikan ralat ini?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Anda mahu menerima kesemua sijil?</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - Ralat SSL</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Ralat SSL:&lt;br/&gt;&lt;br/&gt;untuk: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Anda ingin abaikan ralat ini?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certifactes:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="obsolete">&lt;qt&gt;Sijil:&lt;br/&gt;%1&lt;br/&gt;Anda mahu menerima kesemua sijil ini?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nama</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Nilai</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Penyelia Rangkaian</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Permintaan Rangkaian</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Pengepala Permintaan</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Pengepala Balasan</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Buang</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Buang Semu&amp;a Permintaan</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">Buka Fail</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Nama</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Pengesahan Diperlukan</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Katalaluan:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Tiada di laman ini</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Pengesahan Proxy</translation>
    </message>
    <message>
        <source>ICON</source>
        <translation type="obsolete">ICON</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Berhubung dengan proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Katalaluan:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Ini bukan fail XBEL versi 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Tajuk tidak diketahui</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Lencongan %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Kaedah</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Alamat</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Balasan</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Panjang</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Jenis Kandungan</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Maklumat</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>&lt;</source>
        <translation type="obsolete">&lt;</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation type="obsolete">&gt;</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Sudah</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Opsyen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Bila dibuka:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Tunjuk laman utama saya</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Tunjuk laman kosong</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Kembalikan tetingkap dan tab dari masa lampau</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Laman Utama:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Tetapkan kepada laman semasa</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Buang sejarah:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Selepas sehari</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Selepas seminggu</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Selepas dua minggu</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Selepas sebulan</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Selepas setahun</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Secara manual</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Bila aplikasi keluar</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Buka pautan dari aplikasi:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">Di tab pada tetingkap semasa</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Di tetingkap baru</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Muaturun</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Sentiasa menanya destinasi</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Gunakan destinasi ini:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Penampilan</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Font Standard:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Pilih...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Font lebar-tetap:</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privasi</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Kandungan Web</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Benarkan Plugin</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Benarkan Javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Tunjuk Imej</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookie</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Terima Cookie:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Sentiasa</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Tidak</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Cuma dari laman yang anda pergi</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Pengecualian...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Simpan cookie sehingga:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>ia lupus</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>saya keluar dari aplikasi</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>sehingga 90 hari</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookie...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Pilih tab dan tetingkap sebaik ia dicipta</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Pastikan bila menutup berbilang tab</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Guna server proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Host name:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Nama pengguna:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Katalaluan:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Lanjut</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Style Sheet:</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Papar cuma satu butang tutup bagi keseluruhan tab</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Bahasa digemari untuk melihat laman web:</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Halang Tetingkap Popup</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Membuka capaian</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Capaian yang hendak dibuka di tetingkap baru:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>Di dalam tab terpilih baru di tetingkap semasa</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>Di dalam tab baru di tetingkap semasa</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Di dalam tab semasa</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (Selamat)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (Telus)</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Memuat...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edit</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Cari</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Sumber Laman</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Lihat</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Wrap barisan</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Tunjuk Bar Tab</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Sembunyi Bar Tab</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">&amp;Tab Baru</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Salin Tab</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>T&amp;utup Tab</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Tutup &amp;Lain-lain Tab</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Muatsemula Tab</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Muatsemula Semua Tab</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Tab Baru</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>T&amp;utup Tab</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Tunjuk Tab Seterusnya</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Tunjuk Tab Sebelumnya</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Tab yang baru ditutup</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Tiada tajuk</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Anda benar-benar mahu menutup laman ini?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Anda sudah mengubah laman ini dan jika menutupnya akan menyebabkan kehilangan perubahan ini.
Anda benar-benar mahu teruskan dengan menutup laman ini?
</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Simpan Tab</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Memuat...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Memuat %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Selesai dimuatkan</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Gagal dimuatkan</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Tandabukukan Ke Semua Tab</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>Tiada Carian Sebelum Ini</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Carian Sebelum Ini</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">Hapus Carian Sebelum Ini</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Cadangan</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Ralat memuat laman: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Semasa berhubung ke: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Periksa alamat untuk kesilapan seperti &lt;b&gt;ww&lt;/br&gt;.arora-browser.org yang sepatutnya &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try to check the network connection.</source>
        <translation type="obsolete">Jika alamatnya betul, cuba periksa sambungan rangkaian.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Jika komputer atau rangkaian dilindungi oleh firewall atau proxy, pastikan pelungsur dibenarkan mencapai rangkaian.</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Jika alamat betul, cuba periksa sambungan rangkaian.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Buka di Tetin&amp;gkap Baru</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Buka di &amp;Tab Baru</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Simpan P&amp;autan</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Tanda&amp;buku Pautan Ini</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Salin Lokasi Pautan</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Buka I&amp;mej di Tetingkap Baru</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Buka &amp;Imej di Tab Baru</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>S&amp;impan Imej</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Sa&amp;lin Imej</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>S&amp;alin Lokasi Imej</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Memuat...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Tidak Jumpa</translation>
    </message>
</context>
</TS>
